# ifndef yyMakeLocal
# define yyMakeLocal

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* MakeLocal_Exit) ARGS ((void));

extern void MakeLocal ARGS ((tTree t));

extern void BeginMakeLocal ARGS ((void));
extern void CloseMakeLocal ARGS ((void));

# endif
